@@ -3,6 +3,8 @@
 This module provides the core Shadowstep class for mobile automation testing
 with Appium, including page object management, element interaction, and
 gesture controls.
+
+https://github.com/appium/appium-uiautomator2-driver
 """
 from __future__ import annotations
 
@@ -23,20 +25,18 @@ from selenium.common import (
 )
 from typing_extensions import Self
 
-from shadowstep.base import ShadowstepBase, WebDriverSingleton
 from shadowstep.decorators.decorators import fail_safe
 from shadowstep.element.element import Element
 from shadowstep.exceptions.shadowstep_exceptions import ShadowstepException
 from shadowstep.image.image import ShadowstepImage
 from shadowstep.logcat.shadowstep_logcat import ShadowstepLogcat
-from shadowstep.mobile_commands import MobileCommands
 from shadowstep.navigator.navigator import PageNavigator
 from shadowstep.page_base import PageBaseShadowstep
+from shadowstep.shadowstep_base import ShadowstepBase, WebDriverSingleton
+from shadowstep.ui_automator.mobile_commands import MobileCommands
 from shadowstep.utils.utils import get_current_func_name
 
 if TYPE_CHECKING:
-    from types import ModuleType
-
     import numpy as np
     from numpy._typing import NDArray
     from PIL import Image
@@ -86,7 +86,7 @@ class Shadowstep(ShadowstepBase):
             cls._instance = cls()
         return cls._instance
 
-    def __init__(self) -> None:
+    def __init__(self, *args: object, **kwargs: object) -> None:  # noqa: ARG002
         """Initialize the Shadowstep instance.
 
         Sets up logging, page discovery, and initializes core components.
@@ -97,7 +97,7 @@ class Shadowstep(ShadowstepBase):
 
         self._logcat: ShadowstepLogcat = ShadowstepLogcat(driver_getter=WebDriverSingleton.get_driver)
         self.navigator: PageNavigator = PageNavigator(self)
-        self.mobile_commands: MobileCommands = MobileCommands(self)
+        self.mobile_commands: MobileCommands = MobileCommands()
         self.logger = logging.getLogger(f"{__name__}.{self.__class__.__name__}")
         self._auto_discover_pages()
         self._initialized = True
@@ -131,7 +131,7 @@ class Shadowstep(ShadowstepBase):
                         except Exception as e:  # noqa: BLE001
                             self.logger.warning("⚠️ Import error %s: %s", file, e)
 
-    def _register_pages_from_module(self, module: ModuleType) -> None:
+    def _register_pages_from_module(self, module: Any) -> None:
         try:
             members = inspect.getmembers(module)
             for name, obj in members:
@@ -890,8 +890,8 @@ class Shadowstep(ShadowstepBase):
             width: int,
             height: int,
             direction: str,
-            percent: float,
-            speed: int,
+            percent: float = 0.5,
+            speed: int = 8000,
     ) -> Shadowstep:
         """Perform a swipe gesture within the specified bounding box.
 
